==> ec2-0.16.0-sources.jar: software/amazon/awscdk/services/ec2/VpcPublicSubnet.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Represents a public VPC subnet resource
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.10 (build 35934ad)", date = "2018-11-12T19:56:02.680Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.VpcPublicSubnet")
public class VpcPublicSubnet extends software.amazon.awscdk.services.ec2.VpcSubnet {
    protected VpcPublicSubnet(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    public VpcPublicSubnet(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.ec2.VpcSubnetProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }

    /**
     * Create a default route that points to a passed IGW
     */
    public void addDefaultIGWRouteEntry(final java.lang.String gatewayId) {
        this.jsiiCall("addDefaultIGWRouteEntry", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(gatewayId, "gatewayId is required")).toArray());
    }

    /**
     * Creates a new managed NAT gateway attached to this public subnet.
     * Also adds the EIP for the managed NAT.
     * @return A ref to the the NAT Gateway ID
     */
    public java.lang.String addNatGateway() {
        return this.jsiiCall("addNatGateway", java.lang.String.class);
    }
}

==> ec2-0.17.0-sources.jar: software/amazon/awscdk/services/ec2/VpcPublicSubnet.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Represents a public VPC subnet resource
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.10 (build 35934ad)", date = "2018-11-14T09:49:44.788Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.VpcPublicSubnet")
public class VpcPublicSubnet extends software.amazon.awscdk.services.ec2.VpcSubnet {
    protected VpcPublicSubnet(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    public VpcPublicSubnet(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.ec2.VpcSubnetProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }

    /**
     * Create a default route that points to a passed IGW, with a dependency
     * on the IGW's attachment to the VPC.
     */
    public void addDefaultIGWRouteEntry(final software.amazon.awscdk.services.ec2.cloudformation.InternetGatewayResource gateway, final software.amazon.awscdk.services.ec2.cloudformation.VPCGatewayAttachmentResource gatewayAttachment) {
        this.jsiiCall("addDefaultIGWRouteEntry", Void.class, java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(gateway, "gateway is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(gatewayAttachment, "gatewayAttachment is required"))).toArray());
    }

    /**
     * Creates a new managed NAT gateway attached to this public subnet.
     * Also adds the EIP for the managed NAT.
     * @return A ref to the the NAT Gateway ID
     */
    public java.lang.String addNatGateway() {
        return this.jsiiCall("addNatGateway", java.lang.String.class);
    }
}
